-- Name: CF_Utils
-- Author: Chissel

local lightFileName = "data/light.i3d"
local modDirectory = g_currentModDirectory

CF_Utils = {}
CF_Utils.rootNode = nil

-- Action Events

function CF_Utils.registerActionEventIfNeeded(self, superFunc, hasMenuButtons)
    superFunc(self, hasMenuButtons)

    if CF_Utils.cf_toggleLightEventId ~= nil then
        return
    end

    CF_Utils.rootNode = self.cursor.rootNode
    CF_Utils:loadLight()

    local _, toggleLightEventId = g_inputBinding:registerActionEvent(InputAction.CF_TOGGLE_LIGHT, CF_Utils, CF_Utils.cf_toggleLight, false, true, false, true)

    if toggleLightEventId == nil then
        return
    end

    g_inputBinding:setActionEventTextVisibility(toggleLightEventId, true)
	g_inputBinding:setActionEventTextPriority(toggleLightEventId, GS_PRIO_HIGH)
    CF_Utils.cf_toggleLightEventId = toggleLightEventId
end

function CF_Utils.unregisterActionEventIfNeeded()
    if CF_Utils.cf_toggleLightEventId == nil then
        return
    end

    g_inputBinding:removeActionEvent(CF_Utils.cf_toggleLightEventId)
    CF_Utils.cf_toggleLightEventId = nil

    CF_Utils:deinitLight()
end

-- Load light functions

function CF_Utils:loadLight()
    local lightPath = Utils.getFilename(lightFileName, modDirectory)
    g_i3DManager:loadI3DFileAsync(lightPath, false, false, self.lightLoaded, self, nil)
end

function CF_Utils:lightLoaded(node, failedReason, args)
    if node == nil then
        Logging.error("Load light failed with error: "..failedReason)
        return
    end

    local lightId = getChildAt(node, 0)
    self.cf_lightId = lightId
    link(self.rootNode, self.cf_lightId)
    setVisibility(self.cf_lightId, false)
    delete(node)
end

function CF_Utils:deinitLight()
    unlink(self.cf_lightId)
    self.rootNode = nil
    self.cf_lightId = nil
end

-- Toggle light functions

function CF_Utils:cf_toggleLight()
    if self.cf_lightId == nil then
        Logging.error("Light not available")
        return
    end

    local isVisible = getVisibility(self.cf_lightId)
    setVisibility(self.cf_lightId, not isVisible)
end